@@ -10,7 +10,7 @@ import sys
 __author__ = 'Mansour Moufid'
 __copyright__ = 'Copyright 2021, Mansour Moufid'
 __license__ = 'ISC'
-__version__ = '0.5'
+__version__ = '0.6'
 __email__ = 'mansourmoufid@gmail.com'
 __status__ = 'Development'
 
@@ -60,6 +60,7 @@ CPPFLAGS = [
 LDFLAGS = [
     '-Wl,-z,noexecstack',
     '-Wl,-z,relro',
+    '-pie',
 ]
 
 
@@ -163,10 +164,20 @@ toolchain = os.path.realpath(toolchain)
 sysroot = os.path.join(toolchain, 'sysroot')
 assert os.path.exists(sysroot), sysroot
 
+# distutils.command.build_ext.compiler.find_library_file
+libdirs = [
+    os.path.join(toolchain, 'sysroot', 'usr', 'lib'),
+    os.path.join(sysroot, 'usr', 'lib', triplet, api),
+]
+for dir in libdirs:
+    if os.path.exists(dir):
+        LDFLAGS.append('-L{}'.format(dir))
+
 CC = '{}-clang'.format(target)
 CPP = '{} -E'.format(CC)
 CXX = '{}-clang++'.format(target)
 CFLAGS.append('--target={}'.format(target))
+LDFLAGS.append('--target={}'.format(target))
 CFLAGS.append('-march={}'.format(march))
 CFLAGS.append('-mtune=generic')
 CFLAGS.append('-mfloat-abi=softfp')
@@ -176,6 +187,11 @@ CPPFLAGS.append('-isysroot {}'.format(sysroot))
 CPPFLAGS.append('-isystem {}'.format(
     os.path.join(sysroot, 'usr', 'include', triplet)
 ))
+if abi == 'armeabi-v7a':
+    CFLAGS.append('-mfpu=vfpv3')
+    LDFLAGS.append('-Wl,--fix-cortex-a8')
+elif abi == 'arm64-v8a':
+    CFLAGS.append('-mfpu=neon')
 CXXFLAGS = CFLAGS
 
 CFLAGS = ' '.join(CFLAGS)
@@ -226,6 +242,7 @@ if __name__ == '__main__':
                 print('export {}="{}"'.format(x, os.environ[x]))
 
         vars = (
+            '_PYTHON_HOST_PLATFORM',
             'ABI',
             'API',
             'AR',
@@ -238,8 +255,10 @@ if __name__ == '__main__':
             'CXXFLAGS',
             'LD',
             'LDFLAGS',
+            'LDSHARED',
             'PATH',
             'RANLIB',
+            'READELF',
             'TARGET',
         )
         for var in vars:
